==> scanbot_sdk-2.0.1.tar.gz: ios/Classes/Extensions/SDK/Enums/Barcode formatting/SBSDKDisabilityCertificateDocumentFieldType.swift <==
//
//  SBSDKDisabilityCertificateDocumentFieldType.swift
//  scanbot_sdk
//
//  Created by Danil Voitenko on 08.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKDisabilityCertificateDocumentFieldType {
    var stringName: String? {
        switch self {
        case .requiresCare: return "RequiresCare"
        case .accident: return "Accident"
        case .initialCertificate: return "InitialCertificate"
        case .renewedCertificate: return "RenewedCertificate"
        case .workAccident: return "WorkAccident"
        case .assignedToAccidentInsuranceDoctor: return "AssignedToAccidentInsuranceDoctor"
        case .incapableOfWorkSince: return "IncapableOfWorkSince"
        case .incapableOfWorkUntil: return "IncapableOfWorkUntil"
        case .diagnosedOn: return "DiagnosedOn"
        case .documentDate: return "DocumentDate"
        case .birthDate: return "BirthDate"
        case .firstName: return "FirstName"
        case .lastName: return "LastName"
        case .diagnose: return "Diagnose"
        case .healthInsuranceNumber: return "HealthInsuranceNumber"
        case .insuredPersonNumber: return "InsuredPersonNumber"
        case .status: return "Status"
        case .placeOfOperationNumber: return "PlaceOfOperationNumber"
        case .doctorNumber: return "DoctorNumber"
        @unknown default: preconditionFailure("Unknown SBSDKDisabilityCertificateDocumentFieldType")
        }
    }
    
    init(string: String) {
        switch string {
        case "RequiresCare": self = .requiresCare
        case "Accident": self = .accident
        case "InitialCertificate": self = .initialCertificate
        case "RenewedCertificate": self = .renewedCertificate
        case "WorkAccident": self = .workAccident
        case "AssignedToAccidentInsuranceDoctor": self = .assignedToAccidentInsuranceDoctor
        case "IncapableOfWorkSince": self = .incapableOfWorkSince
        case "IncapableOfWorkUntil": self = .incapableOfWorkUntil
        case "DiagnosedOn": self = .diagnosedOn
        case "DocumentDate": self = .documentDate
        case "BirthDate": self = .birthDate
        case "FirstName": self = .firstName
        case "LastName": self = .lastName
        case "Diagnose": self = .diagnose
        case "HealthInsuranceNumber": self = .healthInsuranceNumber
        case "InsuredPersonNumber": self = .insuredPersonNumber
        case "Status": self = .status
        case "PlaceOfOperationNumber": self = .placeOfOperationNumber
        case "DoctorNumber": self = .doctorNumber
        default: preconditionFailure("Unknown SBSDKDisabilityCertificateDocumentFieldType")
        }
    }
}

==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Enums/Barcode formatting/SBSDKDisabilityCertificateDocumentFieldType.swift <==
//
//  SBSDKDisabilityCertificateDocumentFieldType.swift
//  scanbot_sdk
//
//  Created by Danil Voitenko on 08.05.20.
//

import Foundation
import ScanbotSDK

extension SBSDKMedicalCertificateDocumentFieldType {
    var stringName: String? {
        switch self {
        case .requiresCare: return "RequiresCare"
        case .accident: return "Accident"
        case .initialCertificate: return "InitialCertificate"
        case .renewedCertificate: return "RenewedCertificate"
        case .workAccident: return "WorkAccident"
        case .assignedToAccidentInsuranceDoctor: return "AssignedToAccidentInsuranceDoctor"
        case .incapableOfWorkSince: return "IncapableOfWorkSince"
        case .incapableOfWorkUntil: return "IncapableOfWorkUntil"
        case .diagnosedOn: return "DiagnosedOn"
        case .documentDate: return "DocumentDate"
        case .birthDate: return "BirthDate"
        case .firstName: return "FirstName"
        case .lastName: return "LastName"
        case .diagnose: return "Diagnose"
        case .healthInsuranceNumber: return "HealthInsuranceNumber"
        case .insuredPersonNumber: return "InsuredPersonNumber"
        case .status: return "Status"
        case .placeOfOperationNumber: return "PlaceOfOperationNumber"
        case .doctorNumber: return "DoctorNumber"
        @unknown default: preconditionFailure("Unknown SBSDKDisabilityCertificateDocumentFieldType")
        }
    }
    
    init(string: String) {
        switch string {
        case "RequiresCare": self = .requiresCare
        case "Accident": self = .accident
        case "InitialCertificate": self = .initialCertificate
        case "RenewedCertificate": self = .renewedCertificate
        case "WorkAccident": self = .workAccident
        case "AssignedToAccidentInsuranceDoctor": self = .assignedToAccidentInsuranceDoctor
        case "IncapableOfWorkSince": self = .incapableOfWorkSince
        case "IncapableOfWorkUntil": self = .incapableOfWorkUntil
        case "DiagnosedOn": self = .diagnosedOn
        case "DocumentDate": self = .documentDate
        case "BirthDate": self = .birthDate
        case "FirstName": self = .firstName
        case "LastName": self = .lastName
        case "Diagnose": self = .diagnose
        case "HealthInsuranceNumber": self = .healthInsuranceNumber
        case "InsuredPersonNumber": self = .insuredPersonNumber
        case "Status": self = .status
        case "PlaceOfOperationNumber": self = .placeOfOperationNumber
        case "DoctorNumber": self = .doctorNumber
        default: preconditionFailure("Unknown SBSDKDisabilityCertificateDocumentFieldType")
        }
    }
}
